==> galileo-0.10.0-py3-none-any.whl: galileo/resources/models/column_mapping_config.py <==
from typing import Any, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="ColumnMappingConfig")


@_attrs_define
class ColumnMappingConfig:
    """
    Attributes:
        columns (list[str]):
        flatten (Union[Unset, bool]):  Default: False.
    """

    columns: list[str]
    flatten: Union[Unset, bool] = False
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        columns = self.columns

        flatten = self.flatten

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({"columns": columns})
        if flatten is not UNSET:
            field_dict["flatten"] = flatten

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
        d = src_dict.copy()
        columns = cast(list[str], d.pop("columns"))

        flatten = d.pop("flatten", UNSET)

        column_mapping_config = cls(columns=columns, flatten=flatten)

        column_mapping_config.additional_properties = d
        return column_mapping_config

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> galileo-1.19.0-py3-none-any.whl: galileo/resources/models/column_mapping_config.py <==
from collections.abc import Mapping
from typing import Any, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="ColumnMappingConfig")


@_attrs_define
class ColumnMappingConfig:
    """
    Attributes:
        columns (list[str]):
        flatten (Union[Unset, bool]):  Default: False.
    """

    columns: list[str]
    flatten: Union[Unset, bool] = False
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        columns = self.columns

        flatten = self.flatten

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({"columns": columns})
        if flatten is not UNSET:
            field_dict["flatten"] = flatten

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        columns = cast(list[str], d.pop("columns"))

        flatten = d.pop("flatten", UNSET)

        column_mapping_config = cls(columns=columns, flatten=flatten)

        column_mapping_config.additional_properties = d
        return column_mapping_config

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
